@@ -3,7 +3,7 @@ ldapobject.py - wraps class _ldap.LDAPObject
 
 See http://www.python-ldap.org/ for details.
 
-\$Id: ldapobject.py,v 1.129 2011/12/02 09:42:50 stroeder Exp $
+\$Id: ldapobject.py,v 1.132 2012/03/13 19:23:03 stroeder Exp $
 
 Compability:
 - Tested with Python 2.0+ but should work with Python 1.5.x
@@ -728,6 +728,7 @@ class ReconnectLDAPObject(SimpleLDAPObject):
     self._uri = uri
     self._options = {}
     self._last_bind = None
+    self._pending_reconnect = 0
     SimpleLDAPObject.__init__(self,uri,trace_level,trace_file,trace_stack_limit)
     self._retry_max = retry_max
     self._retry_delay = retry_delay
@@ -762,6 +763,10 @@ class ReconnectLDAPObject(SimpleLDAPObject):
   def reconnect(self,uri):
     # Drop and clean up old connection completely
     # Reconnect
+    while self._pending_reconnect:
+      time.sleep(0.01)
+    else:
+      self._pending_reconnect = 1
     reconnect_counter = self._retry_max
     while reconnect_counter:
       if __debug__ and self._trace_level>=1:
@@ -797,10 +802,12 @@ class ReconnectLDAPObject(SimpleLDAPObject):
           ))
         self._reconnects_done = self._reconnects_done + 1L
         break
+    self._pending_reconnect = 0
+    return # reconnect()
 
   def _apply_method_s(self,func,*args,**kwargs):
     if not self.__dict__.has_key('_l'):
-       self.reconnect(self._uri)
+      self.reconnect(self._uri)
     try:
       return func(self,*args,**kwargs)
     except ldap.SERVER_DOWN:
@@ -813,14 +820,20 @@ class ReconnectLDAPObject(SimpleLDAPObject):
 
   def set_option(self,option,invalue):
     self._options[option] = invalue
-    SimpleLDAPObject.set_option(self,option,invalue)
+    return SimpleLDAPObject.set_option(self,option,invalue)
+
+  def bind_s(self,*args,**kwargs):
+    res = self._apply_method_s(SimpleLDAPObject.bind_s,*args,**kwargs)
+    self._last_bind = (self.bind_s,args,kwargs)
+    return res
 
   def simple_bind_s(self,*args,**kwargs):
+    res = self._apply_method_s(SimpleLDAPObject.simple_bind_s,*args,**kwargs)
     self._last_bind = (self.simple_bind_s,args,kwargs)
-    return SimpleLDAPObject.simple_bind_s(self,*args,**kwargs)
+    return res
 
-  def start_tls_s(self):
-    res = SimpleLDAPObject.start_tls_s(self)
+  def start_tls_s(self,*args,**kwargs):
+    res = self._apply_method_s(SimpleLDAPObject.start_tls_s,*args,**kwargs)
     self._start_tls = 1
     return res
 
@@ -828,8 +841,9 @@ class ReconnectLDAPObject(SimpleLDAPObject):
     """
     sasl_interactive_bind_s(who, auth) -> None
     """
+    res = self._apply_method_s(SimpleLDAPObject.sasl_interactive_bind_s,*args,**kwargs)
     self._last_bind = (self.sasl_interactive_bind_s,args,kwargs)
-    return SimpleLDAPObject.sasl_interactive_bind_s(self,*args,**kwargs)
+    return res
 
   def add_ext_s(self,*args,**kwargs):
     return self._apply_method_s(SimpleLDAPObject.add_ext_s,*args,**kwargs)
